@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: alpine.c 938 2008-02-29 18:18:49Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: alpine.c 1266 2009-07-14 18:39:12Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,6 +23,7 @@ static char rcsid[] = "$Id: alpine.c 938 2008-02-29 18:18:49Z hubert@u.washingto
 #include "../pith/sort.h"
 #include "../pith/options.h"
 #include "../pith/list.h"
+#include "../pith/conf.h"
 
 #include "osdep/debuging.h"
 #include "osdep/termout.gen.h"
@@ -58,6 +60,8 @@ static char rcsid[] = "$Id: alpine.c 938 2008-02-29 18:18:49Z hubert@u.washingto
 #include "colorconf.h"
 #include "print.h"
 #include "after.h"
+#include "smime.h"
+#include "newmail.h"
 #ifndef _WINDOWS
 #include "../pico/osdep/raw.h"	/* for STD*_FD */
 #endif
@@ -163,6 +167,7 @@ main(int argc, char **argv)
     pith_opt_condense_thread_cue   = condensed_thread_cue;
     pith_opt_truncate_sfstr        = truncate_subj_and_from_strings;
     pith_opt_save_and_restore	   = save_and_restore;
+    pith_opt_newmail_announce	   = newmail_status_message;
     pith_opt_newmail_check_cue	   = newmail_check_cue;
     pith_opt_checkpoint_cue	   = newmail_check_point_cue;
     pith_opt_icon_text		   = icon_text;
@@ -182,8 +187,12 @@ main(int argc, char **argv)
     pith_opt_pretty_var_name	   = pretty_var_name;
     pith_opt_pretty_feature_name   = pretty_feature_name;
     pith_opt_closing_stream        = titlebar_stream_closing;
+    pith_opt_current_expunged	   = mm_expunged_current;
+#ifdef	SMIME
+    pith_opt_smime_get_passphrase  = smime_get_passphrase;
+#endif
 #ifdef	ENABLE_LDAP
-    pith_opt_save_ldap_entry	 = save_ldap_entry;
+    pith_opt_save_ldap_entry       = save_ldap_entry;
 #endif
 
     status_message_lock_init();
@@ -287,6 +296,7 @@ main(int argc, char **argv)
 	exit(-1);
     }
 
+    mail_parameters(NULL, SET_QUOTA, (void *) pine_parse_quota);
     /* set some default timeouts in case pinerc is remote */
     mail_parameters(NULL, SET_OPENTIMEOUT, (void *)(long)30);
     mail_parameters(NULL, SET_READTIMEOUT, (void *)(long)15);
@@ -297,6 +307,9 @@ main(int argc, char **argv)
     mail_parameters(NULL, SET_SENDCOMMAND, (void *) pine_imap_cmd_happened);
     mail_parameters(NULL, SET_FREESTREAMSPAREP, (void *) sp_free_callback);
     mail_parameters(NULL, SET_FREEELTSPAREP,    (void *) free_pine_elt);
+#ifdef	SMIME
+    mail_parameters(NULL, SET_FREEBODYSPAREP,   (void *) free_smime_body_sparep);
+#endif
 
     init_pinerc(pine_state, &init_pinerc_debugging);
 
@@ -424,6 +437,11 @@ main(int argc, char **argv)
 
     init_vars(pine_state, process_init_cmds);
 
+#ifdef SMIME
+    if(F_ON(F_DONT_DO_SMIME, ps_global))
+      smime_deinit();
+#endif /* SMIME */
+
 #ifdef	ENABLE_NLS
     /*
      * LC_CTYPE is already set from the set_collation call above.
@@ -2264,6 +2282,10 @@ choose_setup_cmd(int cmd, MSGNO_S *msgmap, SCROLL_S *sparms)
 	srv->cmd = 'z';
 	break;
 
+      case MC_SECURITY :	/* S/MIME setup screen */
+	srv->cmd = 'm';
+	break;
+
       case MC_EXCEPT :
 	srv->exc = !srv->exc;
 	menu_clear_binding(sparms->keys.menu, 'x');
@@ -2315,7 +2337,7 @@ int
 setup_menu(struct pine *ps)
 {
     int         ret = 0, exceptions = 0;
-    int         printer = 0, passwd = 0, config = 0, sig = 0, dir = 0, exc = 0;
+    int         printer = 0, passwd = 0, config = 0, sig = 0, dir = 0, smime = 0, exc = 0;
     SCROLL_S	sargs;
     SRV_S      *srv;
     STORE_S    *store;
@@ -2345,6 +2367,10 @@ setup_menu(struct pine *ps)
     dir++;
 #endif
 
+#ifdef	SMIME
+    smime++;
+#endif
+
     if(ps_global->post_prc)
       exc++;
 
@@ -2427,6 +2453,13 @@ setup_menu(struct pine *ps)
     so_puts(store, _("    command key labels, the titlebar at the top of each page, and quoted\n"));
     so_puts(store, _("    sections of messages you are viewing.\n"));
 
+    if(smime){
+	so_puts(store, "\n");
+	so_puts(store, _("(M) S/MIME:\n"));
+	so_puts(store, _("    Setup for using S/MIME to verify signed messages, decrypt\n"));
+	so_puts(store, _("    encrypted messages, and to sign or encrypt outgoing messages.\n"));
+    }
+
     so_puts(store, "\n");
     so_puts(store, _("(Z) RemoteConfigSetup:\n"));
     so_puts(store, _("    This is a command you will probably only want to use once, if at all.\n"));
@@ -2488,6 +2521,9 @@ setup_menu(struct pine *ps)
     if(!dir)
       clrbitn(SETUP_DIRECTORY, sargs.keys.bitmap);
 
+    if(!smime)
+      clrbitn(SETUP_SMIME, sargs.keys.bitmap);
+
     if(exc)
       menu_init_binding(sargs.keys.menu, 'x', MC_EXCEPT, "X",
 			N_("eXceptions"), SETUP_EXCEPT);
@@ -2644,6 +2680,14 @@ do_setup_task(int command)
 	break;
 #endif
 
+#ifdef	SMIME
+        /*--- S/MIME --*/
+      case 'm':
+	smime_config_screen(ps_global, edit_exceptions);
+	ps_global->mangled_screen = 1;
+	break;
+#endif
+
         /*----- CONFIGURE OPTIONS -----*/
       case 'c':
 	option_screen(ps_global, edit_exceptions);
@@ -3161,6 +3205,10 @@ goodnight_gracey(struct pine *pine_state, int exit_val)
 
     dprint((7, "goodnight_gracey: close config files\n"));    
 
+#ifdef SMIME
+    smime_deinit();
+#endif
+
     free_pinerc_strings(&pine_state);
 
     strncpy(msg, pf, sizeof(msg));
