@@ -1,8 +1,9 @@
 /*
- * $Id: help.h 380 2007-01-23 00:09:18Z hubert@u.washington.edu $
+ * $Id: help.h 769 2007-10-24 00:15:40Z hubert@u.washington.edu $
  *
  * ========================================================================
  * Copyright 2006-2007 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -36,12 +37,14 @@ int	    url_local_config(char *);
 void	    init_helper_getc(char **);
 int	    helper_getc(char *);
 int	    helper(HelpType, char *, int);
+void	    review_messages(void);
+void	    print_help(char **);
 #ifdef	_WINDOWS
 char	   *pcpine_help(HelpType);
 #endif
 #ifdef	DEBUG
-void	dump_config(struct pine *, gf_io_t, int);
-void	dump_pine_struct(struct pine *, gf_io_t);
+void	    dump_config(struct pine *, gf_io_t, int);
+void	    dump_pine_struct(struct pine *, gf_io_t);
 #endif
 
 
