@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: keymenu.c 937 2008-02-28 01:04:46Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: keymenu.c 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -314,6 +315,20 @@ struct key context_fcc_keys[] =
 	WHEREIS_MENU};
 INST_KEY_MENU(c_fcc_km, context_fcc_keys);
 
+static struct key quota_keys[] =
+	{HELP_MENU,
+	NULL_MENU,
+	{"E","Exit",{MC_EXIT,3,{'e','i',ctrl('C')}},KS_EXITMODE},
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	NULL_MENU};
+INST_KEY_MENU(pine_quota_keymenu, quota_keys);
 
 struct key folder_keys[] =
        {HELP_MENU,
@@ -482,7 +497,7 @@ struct key help_keys[] =
 	NEXTPAGE_MENU,
 	PRYNTMSG_MENU,
 	{"Z",N_("Print All"),{MC_PRINTALL,1,{'z'}},KS_NONE},
-	NULL_MENU,
+	{"N",N_("Name"),{MC_EXPORT,1,{'n'}},KS_NONE},
 	WHEREIS_MENU,
 
 	HELP_MENU,
@@ -654,7 +669,7 @@ struct key index_keys[] =
 	/* TRANSLATORS: toggles a collapsed view or an expanded view
 	   of a message thread on and off */
 	{"/",N_("Collapse/Expand"),{MC_COLLAPSE,1,{'/'}},KS_NONE},
-	NULL_MENU,
+	{"@", N_("Quota"), {MC_QUOTA,1,{'@'}}, KS_NONE},
 	NULL_MENU};
 INST_KEY_MENU(index_keymenu, index_keys);
 
@@ -730,7 +745,7 @@ struct key thread_keys[] =
 	ENDKEY_MENU,
 	NULL_MENU,
 	{"/",N_("Collapse/Expand"),{MC_COLLAPSE,1,{'/'}},KS_NONE},
-	NULL_MENU,
+	{"@", N_("Quota"), {MC_QUOTA,1,{'@'}}, KS_NONE},
 	NULL_MENU};
 INST_KEY_MENU(thread_keymenu, thread_keys);
 
@@ -870,8 +885,13 @@ struct key view_keys[] =
 	ENDKEY_MENU,
 	RCOMPOSE_MENU,
 	{"A",N_("TogglePreferPlain"),{MC_TOGGLE,1,{'a'}},KS_NONE},
+#ifdef SMIME
+	{"^D","Decrypt", {MC_DECRYPT,1,{ctrl('d')},KS_NONE}},
+	{"^E","Security", {MC_SECURITY,1,{ctrl('e')},KS_NONE}},
+#else
 	NULL_MENU,
 	NULL_MENU,
+#endif
 	NULL_MENU,
 	NULL_MENU,
 	NULL_MENU,
@@ -930,7 +950,7 @@ INST_KEY_MENU(oe_keymenu, oe_keys);
 struct key choose_setup_keys[] =
        {HELP_MENU,
 	OTHER_MENU,
-	{"E",N_("Exit Setup"),{MC_EXIT,3,{'e','m',ctrl('C')}},KS_EXITMODE},
+	{"E",N_("Exit Setup"),{MC_EXIT,2,{'e',ctrl('C')}},KS_EXITMODE},
 	{"P",N_("Printer"),{MC_PRINTER,1,{'p'}},KS_NONE},
 	/* TRANSLATORS: Change password */
 	{"N",N_("Newpassword"),{MC_PASSWD,1,{'n'}},KS_NONE},
@@ -954,7 +974,8 @@ struct key choose_setup_keys[] =
 	NULL_MENU,
 	/* TRANSLATORS: remote configuration setup */
 	{"Z",N_("RemoteConfigSetup"),{MC_REMOTE,1,{'z'}},KS_NONE},
-	NULL_MENU,
+	/* TRANSLATORS: configure S/MIME */
+	{"M",N_("S/Mime"),{MC_SECURITY,1,{'m'}},KS_NONE},
 	NULL_MENU,
 	PREVPAGE_MENU,
 	NEXTPAGE_MENU,
@@ -2567,6 +2588,50 @@ struct key take_export_keys_lm[] =
 INST_KEY_MENU(take_export_keymenu_lm, take_export_keys_lm);
 
 
+struct key smime_info_keys[] = 
+       {HELP_MENU,
+    	OTHER_MENU,
+	{"<","Back",{MC_VIEW_TEXT,2,{'<',','}},KS_EXITMODE},
+    	NULL_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+	PREVPAGE_MENU,
+	NEXTPAGE_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+
+	HELP_MENU,
+	OTHER_MENU,
+	MAIN_MENU,
+	QUIT_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+    	NULL_MENU,
+	INDEX_MENU,
+    	NULL_MENU,
+    	NULL_MENU};
+INST_KEY_MENU(smime_info_keymenu, smime_info_keys);
+
+
+struct key config_smime_helper_keys[] = 
+       {HELP_MENU,
+	WHEREIS_MENU,
+	EXIT_SETUP_MENU,
+	{"T","[" N_("Transfer") "]", {MC_CHOICE,3,{'t',ctrl('M'),ctrl('J')}}, KS_NONE},
+	PREV_MENU,
+	NEXT_MENU,
+	PREVPAGE_MENU,
+	NEXTPAGE_MENU,
+	NULL_MENU,
+	NULL_MENU,
+	HOMEKEY_MENU,
+	ENDKEY_MENU};
+INST_KEY_MENU(config_smime_helper_keymenu, config_smime_helper_keys);
+
 
 /*
  * Internal prototypes
@@ -2631,6 +2696,9 @@ mark_keymenu_dirty(void)
 void
 output_keymenu(struct key_menu *km, unsigned char *bm, int row, int column)
 {
+#ifdef __CYGWIN__
+    extern char term_name[];
+#endif
     register struct key *k;
     struct key          *last_time;
     int                  i, j,
@@ -2720,7 +2788,11 @@ output_keymenu(struct key_menu *km, unsigned char *bm, int row, int column)
 	char  this_label[6*MAX_LABEL+1];
 
 	j = 6*i - 1;
+#ifndef __CYGWIN__
 	if(i == 1 && !label_color)
+#else
+	if(i == 1 && (!label_color || !struncmp(term_name,"cygwin", 6)))
+#endif
 	  max_column--;  /* Some terminals scroll if you write in the
 			    lower right hand corner. If user has a
 			    label_color set we'll take our chances.
