@@ -1,8 +1,9 @@
 /*
- * $Id: keymenu.h 937 2008-02-28 01:04:46Z hubert@u.washington.edu $
+ * $Id: keymenu.h 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $
  *
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -107,6 +108,7 @@ struct key_menu {
 #define	MC_ROLE		515
 #define	MC_LISTMGR	516
 #define	MC_THRDINDX	517
+#define	MC_SECURITY	518
 
 /* Commands within Screens */
 #define	MC_NEXTITEM	700
@@ -210,7 +212,8 @@ struct key_menu {
 #define	MC_NOT		799
 #define	MC_COLLAPSE	800
 #define	MC_CHK_RECENT	801
-
+#define	MC_DECRYPT	802
+#define MC_QUOTA	803
 
 /*
  * Some standard Key/Command Bindings 
@@ -525,6 +528,7 @@ struct key_menu {
 #define SETUP_SIG		6
 #define SETUP_DIRECTORY		10
 #define SETUP_EXCEPT		14
+#define SETUP_SMIME		16
 #define MAIN_HELP_KEY		0
 #define MAIN_DEFAULT_KEY	3
 #define MAIN_KBLOCK_KEY		9
@@ -541,6 +545,9 @@ struct key_menu {
 #define	NUOV_RELNOTES		10
 #define	DEFAULT_KEY		3
 #define	CHANGEDEF_KEY		10
+#define SMIME_PARENT_KEY	2
+#define DECRYPT_KEY		(VIEW_PIPE_KEY + 7)
+#define SECURITY_KEY		(DECRYPT_KEY + 1)
 
 
 extern struct key_menu	cancel_keymenu,
@@ -553,6 +560,7 @@ extern struct key_menu	cancel_keymenu,
 			c_cfg_km,
 			c_sel_km,
 			c_fcc_km,
+			pine_quota_keymenu,
 			folder_km,
 			folder_sel_km,
 			folder_sela_km,
@@ -591,7 +599,6 @@ extern struct key_menu	cancel_keymenu,
 			addr_s_km_for_url,
 			addr_s_km_exit,
 			addr_s_km_goback,
-			config_text_keymenu,
 			dir_conf_km,
 			sel_from_list,
 			sel_from_list_ctrlc,
@@ -638,7 +645,9 @@ extern struct key_menu	cancel_keymenu,
 			role_color_setting_keymenu,
 			kw_color_setting_keymenu,
 			take_export_keymenu_sm,
-			take_export_keymenu_lm;
+			take_export_keymenu_lm,
+			config_smime_helper_keymenu,
+			smime_info_keymenu;
 
 extern struct key rev_msg_keys[];
 
