@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: mailindx.c 922 2008-02-01 18:42:29Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: mailindx.c 1142 2008-08-13 17:22:21Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -319,7 +320,7 @@ index_lister(struct pine *state, CONTEXT_S *cntxt, char *folder, MAILSTREAM *str
     UCS          ch;
     int		 cmd, which_keys, force,
 		 cur_row, cur_col, km_popped, paint_status;
-    int          old_day = -1;
+    static int   old_day = -1;
     long	 i, j, k, old_max_msgno;
     char        *utf8str;
     IndexType    style, old_style = MsgIndex;
@@ -395,7 +396,7 @@ index_lister(struct pine *state, CONTEXT_S *cntxt, char *folder, MAILSTREAM *str
 	    rfc822_date(db);
 	    parse_date(db, &nnow);
 	    if(old_day != -1 && nnow.day != old_day){
-		clear_index_cache(stream, IC_CLEAR_WIDTHS_DONE);
+		clear_index_cache(stream, 0);
 		state->mangled_body = 1;
 	    }
 
@@ -923,6 +924,8 @@ view_a_thread:
 	    reset_index_border();
 	    break;
 
+	  case MC_QUOTA:
+	    cmd_quota(state);
 
             /*---------- Redraw ----------*/
 	  case MC_REPAINT :
@@ -2825,7 +2828,7 @@ redraw_index_body(void)
 
     (void) update_index(ps_global, current_index_state);
     if(agg)
-      pseudo_selected(current_index_state->msgmap);
+      pseudo_selected(current_index_state->stream, current_index_state->msgmap);
 }
 
 
@@ -2934,7 +2937,7 @@ away.
 void
 index_search(struct pine *state, MAILSTREAM *stream, int command_line, MSGNO_S *msgmap)
 {
-    int         rc, select_all = 0, flags, prefetch;
+    int         rc, select_all = 0, flags, prefetch, we_turned_on = 0;
     long        i, sorted_msg, selected = 0L;
     char        prompt[MAX_SEARCH+50], new_string[MAX_SEARCH+1];
     char        buf[MAX_SCREEN_COLS+1], *p;
@@ -3092,9 +3095,7 @@ index_search(struct pine *state, MAILSTREAM *stream, int command_line, MSGNO_S *
     strncpy(search_string, new_string, sizeof(search_string));
     search_string[sizeof(search_string)-1] = '\0';
 
-#ifndef	DOS
-    intr_handling_on();
-#endif
+    we_turned_on = intr_handling_on();
 
     prefetch = 0;
     for(i = sorted_msg + ((select_all)?0:1);
@@ -3169,7 +3170,7 @@ index_search(struct pine *state, MAILSTREAM *stream, int command_line, MSGNO_S *
 	   && any_lflagged(msgmap, MN_SLCT) > 0L
 	   && !any_lflagged(msgmap, MN_HIDE)
 	   && F_ON(F_AUTO_ZOOM, state))
-	  (void) zoom_index(state, stream, msgmap);
+	  (void) zoom_index(state, stream, msgmap, MN_SLCT);
 	    
 	q_status_message1(SM_ORDER, 0, 3, _("%s messages found matching word"),
 			  long2string(selected));
@@ -3183,9 +3184,8 @@ index_search(struct pine *state, MAILSTREAM *stream, int command_line, MSGNO_S *
     else
       q_status_message(SM_ORDER, 0, 3, _("Word not found"));
 
-#ifndef	DOS
-    intr_handling_off();
-#endif
+    if(we_turned_on)
+      intr_handling_off();
 }
 
 
