@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: newuser.c 673 2007-08-16 22:25:10Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: newuser.c 1266 2009-07-14 18:39:12Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
- * Copyright 2006-2007 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,6 +28,7 @@ static char rcsid[] = "$Id: newuser.c 673 2007-08-16 22:25:10Z hubert@u.washingt
 #include "../pith/msgno.h"
 #include "../pith/filter.h"
 #include "../pith/init.h"
+#include "../pith/margin.h"
 
 
 /*
@@ -59,7 +61,7 @@ new_user_or_version(struct pine *ps)
 				  && isdigit((unsigned char) vers[0])
 				  && vers[1] == '.'
 				  && ps->pine_pre_vers[0] < '5'	/* it was Pine */
-				  && vers[0] == '5'));		/* 1.x Alpine */
+				  && vers[0] >= '5'));		/* Alpine */
 
     text = ps->first_time_user    ? new_user_greeting :
             first_time_alpine_user ? new_alpine_user_greeting : new_version_greeting;
@@ -94,7 +96,7 @@ new_user_or_version(struct pine *ps)
 
 	    gf_link_filter(gf_html2plain,
 			   gf_html2plain_opt("x-alpine-help:",
-					     ps->ttyo->screen_cols, NULL,
+					     ps->ttyo->screen_cols, non_messageview_margin(),
 					     &handles, NULL, GFHP_LOCAL_HANDLES));
 
 	    error = gf_pipe(helper_getc, pc);
