@@ -1,8 +1,9 @@
 /*
- * $Id: termin.gen.h 673 2007-08-16 22:25:10Z hubert@u.washington.edu $
+ * $Id: termin.gen.h 890 2007-12-21 05:34:43Z hubert@u.washington.edu $
  *
  * ========================================================================
  * Copyright 2006-2007 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,8 +20,12 @@
 #include <general.h>
 #include "../radio.h"
 
+/* Useful Macros */
+#define	READ_COMMAND(U)	(read_command_prep() ? read_command(U) : NO_OP_COMMAND)
+
 /* exported prototypes */
 UCS	read_command(char **);
+int	read_command_prep(void);
 int	key_recorder(int);
 int	optionally_enter(char *, int, int, int, char *, ESCKEY_S *, HelpType, int *);
 UCS	validatekeys(UCS);
