@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 1988-2007 University of Washington
+ * Copyright 1988-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,15 +15,13 @@
  * Program:	RFC 2822 and MIME routines
  *
  * Author:	Mark Crispin
- *		Networks and Distributed Computing
- *		Computing & Communications
+ *		UW Technology
  *		University of Washington
- *		Administration Building, AG-44
  *		Seattle, WA  98195
- *		Internet: MRC@CAC.Washington.EDU
+ *		Internet: MRC@Washington.EDU
  *
  * Date:	27 July 1988
- * Last Edited:	11 September 2007
+ * Last Edited:	14 May 2008
  *
  * This original version of this file is
  * Copyright 1988 Stanford University
@@ -130,6 +128,7 @@ void rfc822_parse_msg_full (ENVELOPE **en,BODY **bdy,char *s,unsigned long i,
   ENVELOPE *env = (*en = mail_newenvelope ());
   BODY *body = bdy ? (*bdy = mail_newbody ()) : NIL;
   long MIMEp = -1;		/* flag that MIME semantics are in effect */
+  long PathP = NIL;             /* flag that a Path: was seen */
   parseline_t pl = (parseline_t) mail_parameters (NIL,GET_PARSELINE,NIL);
   if (!host) host = BADHOST;	/* make sure that host is non-null */
   while (i && *s != '\n') {	/* until end of header */
@@ -232,6 +231,9 @@ void rfc822_parse_msg_full (ENVELOPE **en,BODY **bdy,char *s,unsigned long i,
 	  *t++ = '\0';
 	}
 	break;
+      case 'P':                 /* possible Path: */
+	if (!strcmp (tmp+1,"ATH")) env->ngpathexists = T;
+	break;
       case 'R':			/* possible Reply-To: */
 	if (!strcmp (tmp+1,"EPLY-TO"))
 	  rfc822_parse_adrlist (&env->reply_to,d,host);
@@ -304,8 +306,17 @@ void rfc822_parse_content (BODY *body,STRING *bs,char *h,unsigned long depth,
 	}
 	if (c == '\n') body->size.lines++;
       }
-				/* otherwise assume US-ASCII */
-      if (!body->parameter->value) body->parameter->value = cpystr("US-ASCII");
+				/* 7-bit content */
+      if (!body->parameter->value) switch (body->encoding) {
+      case ENC7BIT:		/* unadorned 7-bit */
+      case ENC8BIT:		/* unadorned 8-bit (but 7-bit content) */
+      case ENCBINARY:		/* binary (but 7-bit content( */
+	body->parameter->value = cpystr ("US-ASCII");
+	break;
+      default:			/* QUOTED-PRINTABLE, BASE64, etc. */
+	body->parameter->value = cpystr ("X-UNKNOWN");
+	break;
+      }
     }
 				/* just count lines */
     else while (i--) if ((SNX (bs)) == '\n') body->size.lines++;
@@ -503,7 +514,10 @@ void rfc822_parse_content (BODY *body,STRING *bs,char *h,unsigned long depth,
 	  if (!part->body.parameter) {
 	    part->body.parameter = mail_newbody_parameter ();
 	    part->body.parameter->attribute = cpystr ("CHARSET");
-	    part->body.parameter->value = cpystr ("US-ASCII");
+				/* only assume US-ASCII if 7BIT */
+	    part->body.parameter->value =
+	      cpystr ((part->body.encoding == ENC7BIT) ?
+		      "US-ASCII" : "X-UNKNOWN");
 	  }
 	  break;
 	case TYPEMESSAGE:	/* encapsulated message in digest */
@@ -1341,6 +1355,7 @@ char *rfc822_skip_comment (char **s,long trim)
 
 static long rfc822_output_char (RFC822BUFFER *buf,int c)
 {
+  if ((buf->cur == buf->end) && !rfc822_output_flush (buf)) return NIL;
   *buf->cur++ = c;		/* add character, soutr buffer if full */
   return (buf->cur == buf->end) ? rfc822_output_flush (buf) : LONGT;
 }
@@ -1364,7 +1379,8 @@ static long rfc822_output_data (RFC822BUFFER *buf,char *string,long len)
       len -= i;
     }
 				/* soutr buffer now if full */
-    if (len && !rfc822_output_flush (buf)) return NIL;
+    if ((len || (buf->cur == buf->end)) && !rfc822_output_flush (buf))
+      return NIL;
   }
   return LONGT;
 }
@@ -1554,7 +1570,7 @@ long rfc822_output_address_list (RFC822BUFFER *buf,ADDRESS *adr,long pretty,
 	  ((!--n && adr->next && adr->next->mailbox) &&
 	   !rfc822_output_string (buf,", "))) return NIL;
     }
-    if (pretty &&		/* pretty printing? */
+    if (pretty && adr->next &&	/* pretty printing? */
 	((pretty += ((buf->cur > base) ? buf->cur - base :
 		     (buf->end - base) + (buf->cur - buf->beg))) >= 78)) {
       if (!(rfc822_output_string (buf,"\015\012") &&
