@@ -21,7 +21,7 @@
  *		Internet: MRC@Washington.EDU
  *
  * Date:	1 August 1988
- * Last Edited:	15 February 2008
+ * Last Edited:	23 February 2009
  */
 
 #include <grp.h>
@@ -931,10 +931,16 @@ char *myusername_full (unsigned long *flags)
 
 char *mylocalhost ()
 {
-  char tmp[MAILTMPLEN];
   if (!myLocalHost) {
-    gethostname(tmp,MAILTMPLEN);/* get local host name */
-    myLocalHost = cpystr (tcp_canonical (tmp));
+    char *s,tmp[MAILTMPLEN];
+    char *t = "unknown";
+    tmp[0] = tmp[MAILTMPLEN-1] = '\0';
+    if (!gethostname (tmp,MAILTMPLEN-1) && tmp[0]) {
+				/* sanity check of name */
+      for (s = tmp; (*s > 0x20) && (*s < 0x7f); ++s);
+      if (!*s) t = tcp_canonical (tmp);
+    }
+    myLocalHost = cpystr (t);
   }
   return myLocalHost;
 }
@@ -1807,7 +1813,7 @@ long path_create (MAILSTREAM *stream,char *path)
   restrictBox = NIL;		/* can't restrict */
   if (blackBox) {		/* if black box */
 				/* toss out driver dependent names */
-    printf (path,"%s/INBOX",mymailboxdir ());
+    sprintf (path,"%s/INBOX",mymailboxdir ());
     blackBox = NIL;		/* well that's evil - evil is going on */
     ret = mail_create (stream,path);
     blackBox = T;		/* restore the box */
