@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 1988-2007 University of Washington
+ * Copyright 1988-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	1 August 1988
- * Last Edited:	31 January 2007
+ * Last Edited:	13 January 2008
  */
 
 #include "ip_unix.c"
@@ -55,6 +55,8 @@ extern long maxposint;		/* get this from write.c */
 
 int tcp_socket_open (int family,void *adr,size_t adrlen,unsigned short port,
 		     char *tmp,int *ctr,char *hst);
+static char *tcp_getline_work (TCPSTREAM *stream,unsigned long *size,
+			       long *contd);
 long tcp_abort (TCPSTREAM *stream);
 char *tcp_name (struct sockaddr *sadr,long flag);
 char *tcp_name_valid (char *s);
@@ -449,51 +451,74 @@ TCPSTREAM *tcp_aopen (NETMBX *mb,char *service,char *usrbuf)
   return stream;		/* return success */
 }
 
-/* TCP/IP receive line
- * Accepts: TCP/IP stream
+/* TCP receive line
+ * Accepts: TCP stream
  * Returns: text line string or NIL if failure
  */
 
 char *tcp_getline (TCPSTREAM *stream)
 {
-  int n,m;
-  char *st,*ret,*stp;
-  char c = '\0';
-  char d;
+  unsigned long n,contd;
+  char *ret = tcp_getline_work (stream,&n,&contd);
+  if (ret && contd) {		/* got a line needing continuation? */
+    STRINGLIST *stl = mail_newstringlist ();
+    STRINGLIST *stc = stl;
+    do {			/* collect additional lines */
+      stc->text.data = (unsigned char *) ret;
+      stc->text.size = n;
+      stc = stc->next = mail_newstringlist ();
+      ret = tcp_getline_work (stream,&n,&contd);
+    } while (ret && contd);
+    if (ret) {			/* stash final part of line on list */
+      stc->text.data = (unsigned char *) ret;
+      stc->text.size = n;
+				/* determine how large a buffer we need */
+      for (n = 0, stc = stl; stc; stc = stc->next) n += stc->text.size;
+      ret = fs_get (n + 1);	/* copy parts into buffer */
+      for (n = 0, stc = stl; stc; n += stc->text.size, stc = stc->next)
+	memcpy (ret + n,stc->text.data,stc->text.size);
+      ret[n] = '\0';
+    }
+    mail_free_stringlist (&stl);/* either way, done with list */
+  }
+  return ret;
+}
+
+/* TCP receive line or partial line
+ * Accepts: TCP stream
+ *	    pointer to return size
+ *	    pointer to return continuation flag
+ * Returns: text line string, size and continuation flag, or NIL if failure
+ */
+
+static char *tcp_getline_work (TCPSTREAM *stream,unsigned long *size,
+			       long *contd)
+{
+  unsigned long n;
+  char *s,*ret,c,d;
+  *contd = NIL;			/* assume no continuation */
 				/* make sure have data */
   if (!tcp_getdata (stream)) return NIL;
-  st = stream->iptr;		/* save start of string */
-  n = 0;			/* init string count */
-  while (stream->ictr--) {	/* look for end of line */
+  for (s = stream->iptr, n = 0, c = '\0'; stream->ictr--; n++, c = d) {
     d = *stream->iptr++;	/* slurp another character */
     if ((c == '\015') && (d == '\012')) {
       ret = (char *) fs_get (n--);
-      memcpy (ret,st,n);	/* copy into a free storage string */
+      memcpy (ret,s,*size = n);	/* copy into a free storage string */
       ret[n] = '\0';		/* tie off string with null */
       return ret;
     }
-    n++;			/* count another character searched */
-    c = d;			/* remember previous character */
   }
 				/* copy partial string from buffer */
-  memcpy ((ret = stp = (char *) fs_get (n)),st,n);
-  if (tcp_getdata (stream)) {	/* get more data from the net */
+  memcpy ((ret = (char *) fs_get (n)),s,*size = n);
+				/* get more data from the net */
+  if (!tcp_getdata (stream)) fs_give ((void **) &ret);
 				/* special case of newline broken by buffer */
-    if ((c == '\015') && (*stream->iptr == '\012')) {
-      stream->iptr++;		/* eat the line feed */
-      stream->ictr--;
-      ret[n - 1] = '\0';	/* tie off string with null */
-    }
-				/* else recurse to get remainder */
-    else if (st = tcp_getline (stream)) {
-      ret = (char *) fs_get (n + 1 + (m = strlen (st)));
-      memcpy (ret,stp,n);	/* copy first part */
-      memcpy (ret + n,st,m);	/* and second part */
-      fs_give ((void **) &stp);	/* flush first part */
-      fs_give ((void **) &st);	/* flush second part */
-      ret[n + m] = '\0';	/* tie off string with null */
-    }
+  else if ((c == '\015') && (*stream->iptr == '\012')) {
+    stream->iptr++;		/* eat the line feed */
+    stream->ictr--;
+    ret[*size = --n] = '\0';	/* tie off string with null */
   }
+  else *contd = LONGT;		/* continuation needed */
   return ret;
 }
 
@@ -560,7 +585,7 @@ long tcp_getbuffer (TCPSTREAM *stream,unsigned long size,char *s)
 	if (tcpdebug) mm_log ("Successfully read TCP buffer",TCPDEBUG);
       }
 				/* timeout, punt unless told not to */
-      else if (!tmoh || !(*tmoh) (now - t,now - tl)) {
+      else if (!tmoh || !(*tmoh) (now - t,now - tl, stream->host)) {
 	if (tcpdebug) mm_log ("TCP buffer read timeout",TCPDEBUG);
 	return tcp_abort (stream);
       }
@@ -620,7 +645,7 @@ long tcp_getdata (TCPSTREAM *stream)
       if (tcpdebug) mm_log ("Successfully read TCP data",TCPDEBUG);
     }
 				/* timeout, punt unless told not to */
-    else if (!tmoh || !(*tmoh) (now - t,now - tl)) {
+    else if (!tmoh || !(*tmoh) (now - t,now - tl, stream->host)) {
       if (tcpdebug) mm_log ("TCP data read timeout",TCPDEBUG);
       return tcp_abort (stream);/* error or timeout no-continue */
     }
@@ -691,7 +716,7 @@ long tcp_sout (TCPSTREAM *stream,char *string,unsigned long size)
       if (tcpdebug) mm_log ("successfully wrote to TCP",TCPDEBUG);
     }
 				/* timeout, punt unless told not to */
-    else if (!tmoh || !(*tmoh) (now - t,now - tl)) {
+    else if (!tmoh || !(*tmoh) (now - t,now - tl, stream->host)) {
       if (tcpdebug) mm_log ("TCP write timeout",TCPDEBUG);
       return tcp_abort (stream);
     }
@@ -1012,3 +1037,7 @@ long tcp_isclienthost (char *host)
     }
   return ret;
 }
+
+/* Following statement must be at end of this module */
+
+#undef fork			/* undo any use of vfork() */
