@@ -1,10 +1,11 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: main.c 737 2007-10-03 19:40:34Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: main.c 1184 2008-12-16 23:52:15Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
- * Copyright 2006-2007 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,6 +33,7 @@ static char rcsid[] = "$Id: main.c 737 2007-10-03 19:40:34Z hubert@u.washington.
 #include	"../c-client/rfc822.h"
 #include	"../pith/osdep/collate.h"
 #include	"../pith/charconv/filesys.h"
+#include	"../pith/charconv/utf8.h"
 #include	"../pith/conf.h"
 
 
@@ -159,7 +161,7 @@ main(int argc, char *argv[])
     int      setlocale_collate = 1;
     char     bname[NBUFN];		/* buffer name of file to read	*/
     char    *file_to_edit = NULL;
-    char    *display_charmap = NULL;
+    char    *display_charmap = NULL, *dc;
     char    *keyboard_charmap = NULL;
     int      use_system = 0;
     char    *err = NULL;
@@ -186,8 +188,8 @@ main(int argc, char *argv[])
     if(display_character_set)
       display_charmap = cpstr(display_character_set);
 #if   HAVE_LANGINFO_H && defined(CODESET)
-    else
-      display_charmap = cpstr(nl_langinfo(CODESET));
+    else if((dc = nl_langinfo_codeset_wrapper()) != NULL)
+      display_charmap = cpstr(dc);
 #endif
 
     if(!display_charmap)
@@ -585,7 +587,15 @@ Loop:
             gmode ^= MDDOTSOK;          /* show dot files */
             break;
 	  case 'b':
+#ifdef notdef
+    /*
+     * Make MDREPLACE always on instead
+     * Don't leave this to allow turning off of MDREPLACE because the
+     * polarity of -b will have changed. Don't think anybody wants to
+     * turn it off.
+     */
 	    gmode ^= MDREPLACE;  /* -b for replace string in where is command */
+#endif
 	    break;
 	  case 'd':			/* -d for rebind delete key */
 	    bindtokey(0x7f, forwdel);
