@@ -1,8 +1,9 @@
 /*
- * $Id: color.h 673 2007-08-16 22:25:10Z hubert@u.washington.edu $
+ * $Id: color.h 1012 2008-03-26 00:44:22Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006-2007 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,6 +30,9 @@ void	 StartUnderline(void);
 void	 EndUnderline(void);
 int      pico_trans_color(void);
 void	 pico_endcolor(void);
+void	 pico_toggle_color(int);
+void	 pico_set_nfg_color(void);
+void	 pico_set_nbg_color(void);
 
 
 #endif /* PICO_OSDEP_COLOR_INCLUDED */
