@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: filesys.c 676 2007-08-20 19:46:37Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: filesys.c 770 2007-10-24 00:23:09Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -712,7 +713,7 @@ tmpname(char *dir, char *name)
 {
     char *t;
 #ifndef _WINDOWS
-    if((t = temp_nam((dir && *dir) ? dir : NULL, "pico.", 0)) != NULL){
+    if((t = temp_nam((dir && *dir) ? dir : NULL, "pico.")) != NULL){
 #else /* _WINDOWS */
     char  tmp[_MAX_PATH];
 
@@ -724,7 +725,7 @@ tmpname(char *dir, char *name)
 	   && fexist(dir, "w", (off_t *) NULL) == FIOSUC))
 	dir = "c:\\";
       
-    if((t = temp_nam_ext(dir, "ae", 0, "txt")) != NULL){
+    if((t = temp_nam_ext(dir, "ae", "txt")) != NULL){
 #endif /* _WINDOWS */
 	strncpy(name, t, NFILEN-1);
 	name[NFILEN-1] = '\0';
