@@ -1,10 +1,11 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: msdlg.c 933 2008-02-22 23:52:28Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: msdlg.c 1025 2008-04-08 22:59:38Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -82,7 +83,7 @@ typedef struct {
     LPTSTR 	string;			/* Resulting string. */
     int		strlen;			/* Length of buffer. */
     int		append;			/* Append to existing string. */
-    int		passwd;			/* Passwd, don't echo. */
+    int		passwd;			/* Passwd, don't echo (1 use asterisk, 10 space). */
     unsigned	flags;			/* other flags. */
     int		dflt;
     int		cancel;
@@ -292,7 +293,7 @@ mswin_dialog_proc (HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam)
 	SetDlgItemText(hDlg, IDC_RESPONCE, gOEInfo.string);
 
 	SendDlgItemMessage (hDlg, IDC_RESPONCE, EM_SETPASSWORDCHAR,
-		gOEInfo.passwd ? '*' : 0, 0L);
+		(gOEInfo.passwd == 1) ? '*' : gOEInfo.passwd ? ' ' : 0, 0L);
 	SendDlgItemMessage (hDlg, IDC_RESPONCE, EM_LIMITTEXT, 
 		gOEInfo.strlen - 1, 0L);
 	l = (long) lstrlen(gOEInfo.string);
