@@ -1,10 +1,11 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: search.c 848 2007-12-06 19:57:49Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: search.c 1266 2009-07-14 18:39:12Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
- * Copyright 2006 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -395,7 +396,7 @@ replace_pat(UCS *defpat, int *wrapt)
 	    *promptp = '\0';
 	}
 
-	prompt[sizeof(prompt)-1] = '\0';
+	prompt[NPMT-1] = '\0';
 
 	status = mlreplyd(prompt, lpat, NPAT, QDEFLT, menu_pat);
 
@@ -463,8 +464,10 @@ replace_pat(UCS *defpat, int *wrapt)
 	    break;
 
 	  default:
-	    if(status == ABORT)
+	    if(status == ABORT){
 	      emlwrite(_("Replacement Cancelled"), NULL);
+	      pico_refresh(FALSE, 1);
+	    }
 	    else{
 		mlerase();
 		chword(defpat, origpat);
