@@ -1,10 +1,11 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: word.c 537 2007-04-24 23:27:18Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: word.c 769 2007-10-24 00:15:40Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -181,7 +182,7 @@ ucs4_isalpha(UCS c)
 int
 ucs4_isspace(UCS c)
 {
-    return(c < 0xff && isspace((unsigned char) c) || SPECIAL_SPACE(c));
+    return((c < 0xff && isspace((unsigned char) c)) || SPECIAL_SPACE(c));
 }
 
 int
@@ -435,7 +436,7 @@ is_user_separator(UCS c)
  * Return number of quotes if whatever starts the line matches the quote string
  */
 int
-quote_match(UCS *q, LINE *l, UCS *buf, int buflen)
+quote_match(UCS *q, LINE *l, UCS *buf, size_t buflen)
 {
     register int i, n, j, qb;
 
@@ -452,7 +453,7 @@ quote_match(UCS *q, LINE *l, UCS *buf, int buflen)
 	n++;
 	if((!qb && q[i] == '\0') || (qb && q[i+1] == '\0')){
 	    if(ucs4_strlen(buf) + ucs4_strlen(q) + 1 < buflen){
-		ucs4_strncat(buf, q, buflen-ucs4_strlen(q));
+		ucs4_strncat(buf, q, buflen-ucs4_strlen(q)-1);
 		buf[buflen-1] = '\0';
 		if(qb && (j > llength(l) || lgetc(l, j).c != ' '))
 		  buf[ucs4_strlen(buf)-1] = '\0';
@@ -471,7 +472,6 @@ quote_match(UCS *q, LINE *l, UCS *buf, int buflen)
 int
 fillbuf(int f, int n)
 {
-    int i, lastflagsave;
     LINE *eobline;
     REGION region;
 
@@ -831,7 +831,7 @@ fillregion(UCS *qstr, REGION *addedregion)
 {
     long    c, sz, last_char = 0;
     int	    i, j, qlen, same_word,
-	    spaces, word_len, word_ind, line_len, qn, ww;
+	    spaces, word_len, word_ind, line_len, ww;
     int     starts_midline = 0;
     int     ends_midline = 0;
     int     offset_into_start;
@@ -901,13 +901,11 @@ fillregion(UCS *qstr, REGION *addedregion)
 
 	    if(!spaces)
 	      spaces++;
-	    same_word = 0;
 	    break;
 
 	  case TAB :
 	  case ' ' :
 	    spaces++;
-	    same_word = 0;
 	    break;
 
 	  default :
@@ -916,6 +914,7 @@ fillregion(UCS *qstr, REGION *addedregion)
 		   && line_len + word_len + 1 > fillcol
 		   && ((ucs4_isspace(line_last))
 		       || (linsert(1, ' ')))
+		   && same_word == 0
 		   && (line_len = fpnewline(qstr)))
 		  line_last = ' ';	/* no word-flush space! */
 
@@ -934,7 +933,7 @@ fillregion(UCS *qstr, REGION *addedregion)
 			line_len += 2;
 		    }
 
-		    word_len = word_ind = 0;
+		    same_word = word_len = word_ind = 0;
 		}
 
 		spaces = 0;
@@ -942,12 +941,12 @@ fillregion(UCS *qstr, REGION *addedregion)
 
 	    if(word_ind + 1 >= NSTRING){
 		/* Magic!  Fake that we output a wrapped word */
-		if((line_len - qlen > 0) && !same_word++){
+		if((line_len - qlen > 0) && same_word == 0){
 		    if(!ucs4_isspace(line_last))
 		      linsert(1, ' ');
 		    line_len = fpnewline(qstr);
 		}
-
+		same_word = 1;
 		line_len += word_len;
 		for(j = 0; j < word_ind; j++)
 		  linsert(1, word[j]);
@@ -965,7 +964,7 @@ fillregion(UCS *qstr, REGION *addedregion)
     }
 
     if(word_len){
-	if((line_len - qlen > 0) && (line_len + word_len + 1 > fillcol)){
+	if((line_len - qlen > 0) && (line_len + word_len + 1 > fillcol) && same_word == 0){
 	    if(!ucs4_isspace(line_last))
 	      linsert(1, ' ');
 	    (void) fpnewline(qstr);
