@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: addrstring.c 671 2007-08-15 20:28:09Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: addrstring.c 770 2007-10-24 00:23:09Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -59,6 +60,27 @@ addr_string(struct mail_address *addr, char *buf, size_t buflen)
 }
 
 
+/*
+ * Same as addr_string only it doesn't have to be a
+ * single address.
+ */
+char *
+addr_string_mult(struct mail_address *addr, char *buf, size_t buflen)
+{
+    RFC822BUFFER rbuf;
+
+    *buf = '\0';
+    rbuf.f   = dummy_soutr;
+    rbuf.s   = NULL;
+    rbuf.beg = buf;
+    rbuf.cur = buf;
+    rbuf.end = buf+buflen-1;
+    rfc822_output_address_list(&rbuf, addr, 0L, NULL);
+    *rbuf.cur = '\0';
+    return(buf);
+}
+
+
 /*
  * Format an address structure into a simple string: "mailbox@host"
  *
