@@ -1,10 +1,11 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: charset.c 875 2007-12-17 18:39:47Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: charset.c 1032 2008-04-11 00:30:04Z hubert@u.washington.edu $";
 #endif
 
 /*
  * ========================================================================
- * Copyright 2006-2007 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +21,7 @@ static char rcsid[] = "$Id: charset.c 875 2007-12-17 18:39:47Z hubert@u.washingt
 #include "../pith/state.h"
 #include "../pith/conf.h"
 #include "../pith/escapes.h"
-#include "../pith/rfc2231.h"
+#include "../pith/mimedesc.h"
 #include "../pith/filter.h"
 #include "../pith/string.h"
 #include "../pith/options.h"
@@ -48,7 +49,7 @@ body_charset(MAILSTREAM *stream, long int msgno, unsigned char *section)
 
 
     if((body = mail_body(stream, msgno, section)) && body->type == TYPETEXT){
-	if(!(charset = rfc2231_get_param(body->parameter, "charset", NULL, NULL)))
+	if(!(charset = parameter_val(body->parameter, "charset")))
 	  charset = cpystr("US-ASCII");
 
 	return(charset);
@@ -185,11 +186,10 @@ rfc1522_decode_to_utf8(unsigned char *d, size_t len, char *s)
     *d = '\0';					/* init destination */
 
     while(s && (sw = strstr(s, RFC1522_INIT))){
+	if(!rv)  /* there's something to do, init it */
+	  rv = d;
 	/* validate the rest of the encoded-word */
 	if(rfc1522_valid(sw, &cset, &enc, &txt, &ew)){
-	    if(!rv)
-	      rv = d;				/* remember start of dest */
-
 	    /*
 	     * We may have been putting off copying the first part of the
 	     * source while waiting to see if we have to copy at all.
@@ -286,20 +286,16 @@ rfc1522_decode_to_utf8(unsigned char *d, size_t len, char *s)
 	      lang[-1] = '*';
 	}
 	else{
-
 	    /*
 	     * Found intro, but bogus data followed, treat it as normal text.
 	     */
-
-	    /* if already copying to destn, copy it */
 	    l = (sw - s) + RFC1522_INIT_L;
-	    if(rv){
-		rfc1522_copy_and_transliterate(rv, &d, len, (unsigned char *) s, l, NULL);
-		*d = '\0';
-		s += l;				/* advance s beyond intro */
-	    }
-	    else	/* probably won't have to copy it at all, wait */
-	      s += l;
+	    rfc1522_copy_and_transliterate(rv, &d, len, (unsigned char *) s, l, NULL);
+	    for(; isspace((unsigned char) *(s+l)) && d-rv<len-1;l++)
+		*d++ = *(s+l);  /* copy any trailing space */
+	    rv[len-1] = '\0';
+	    *d = '\0';
+	    s += l;
 	}
     }
 
@@ -459,6 +455,15 @@ rfc1522_copy_and_transliterate(unsigned char  *rv,
 		}
 	    }
 	}
+	else if((cset=ps_global->VAR_UNK_CHAR_SET)
+		&& strucmp((char *) cset, "us-ascii")
+	        && strucmp((char *) cset, "utf-8")
+		&& utf8_charset(cset)){
+		if(!utf8_text(&src, cset, &xsrc, 0L)){
+		    /* should not happen */
+		    panic("c-client failed to transliterate recognized character set");
+		}
+	}
 	else{
 	    /* unknown bytes - mask off high bit chars */
 	    for(i = 0; i < l; i++)
