@@ -1,8 +1,9 @@
 /*
- * $Id: conftype.h 1122 2008-08-02 00:32:26Z hubert@u.washington.edu $
+ * $Id: conftype.h 1155 2008-08-21 18:33:21Z hubert@u.washington.edu $
  *
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -282,6 +283,8 @@ typedef	enum {    V_PERSONAL_NAME = 0
 #ifdef	ENABLE_LDAP
 		, V_LDAP_SERVERS  /* should be last so make will work right */
 #endif
+		, V_RSS_NEWS
+		, V_RSS_WEATHER
 		, V_WP_INDEXHEIGHT
 		, V_WP_INDEXLINES
 		, V_WP_AGGSTATE
@@ -426,6 +429,7 @@ typedef enum {
 	F_TCAP_WINS,
 	F_ENABLE_SIGDASHES,
 	F_ENABLE_STRIP_SIGDASHES,
+	F_NEW_THREAD_ON_BLANK_SUBJECT,
 	F_QUELL_PARTIAL_FETCH,
 	F_QUELL_PERSONAL_NAME_PROMPT,
 	F_QUELL_USER_ID_PROMPT,
@@ -509,6 +513,7 @@ typedef enum {
 	F_AUTO_UNSELECT,
 	F_SEND_CONFIRM_ON_EXPAND,
 	F_ENABLE_NEWMAIL_SOUND,
+	F_RENDER_HTML_INTERNALLY,
 	F_ENABLE_JUMP_CMD,
 	F_FORWARD_AS_ATTACHMENT,
 #ifndef	_WINDOWS
