@@ -1,8 +1,9 @@
 /*
- * $Id: mailindx.h 671 2007-08-15 20:28:09Z hubert@u.washington.edu $
+ * $Id: mailindx.h 925 2008-02-06 02:03:01Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006-2007 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,7 +44,7 @@ void	       setup_for_thread_index_screen(void);
 INDEX_PARSE_T *itoken(int);
 void	       load_overview(MAILSTREAM *, unsigned long, OVERVIEW *, imapuid_t);
 ICE_S	      *build_header_work(struct pine *, MAILSTREAM  *, MSGNO_S *, long, long, int, int *);
-char	      *simple_index_line(char *, size_t, int, ICE_S *, long);
+char	      *simple_index_line(char *, size_t, ICE_S *, long);
 int	       resent_to_us(INDEXDATA_S *);
 int	       parsed_resent_to_us(char *);
 ADDRESS	      *fetch_cc(INDEXDATA_S *);
