@@ -1,8 +1,9 @@
 /*
- * $Id: mailpart.h 136 2006-09-22 20:06:05Z hubert@u.washington.edu $
+ * $Id: mailpart.h 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,6 +32,9 @@
 			 || ((t) == TYPETEXT                          \
  		   && (s) && !strucmp((s),"X-VCARD")))
 
+/* Is this a multipart signed? */
+#define	MIME_MULT_SIGNED(t,s)	((t) == TYPEMULTIPART && (s) && !strucmp((s),"signed"))
+
 
 #define	MIME_MSG_A(a)	MIME_MSG((a)->body->type, (a)->body->subtype)
 
