@@ -3,6 +3,7 @@
  *
  * ========================================================================
  * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,7 +33,7 @@
 #include "state.h"			/* for struct pine */
 #include "adrbklib.h"			/* for SAVE_STATE_S */
 #ifdef	ENABLE_LDAP
-#include "ldap.h"			/* for LDAP_SERV_RES_S */
+#include "ldap.h"
 #endif
 
 
@@ -67,7 +68,7 @@ extern int  (*pith_opt_rfc2369_editorial)(long, HANDLE_S **, int, int, gf_io_t);
 /*
  * optional hook in ldap.c:wp_lookups to ask user where to save chosen LDAP result
  */
-extern void (*pith_opt_save_ldap_entry)(struct pine *, LDAP_SERV_RES_S *, int);
+extern void (*pith_opt_save_ldap_entry)(struct pine *, LDAP_CHOOSE_S *, int);
 #endif
 
 /*
@@ -81,6 +82,7 @@ extern void (*pith_opt_save_and_restore)(int, SAVE_STATE_S *);
  * optional hooks in newmail.c:new_mail to allow for various indicators
  * during the new mail check/arrival and checkpoint process
  */
+extern void (*pith_opt_newmail_announce)(MAILSTREAM *, long, long);
 extern void (*pith_opt_newmail_check_cue)(int);
 extern void (*pith_opt_checkpoint_cue)(int);
 extern void (*pith_opt_icon_text)(char *, int);
@@ -205,4 +207,22 @@ extern int (*pith_opt_truncate_sfstr)(void);
 extern void (*pith_opt_closing_stream)(MAILSTREAM *);
 
 
+/*
+ * Callback from mm_expunged to let us know the "current"
+ * message was expunged
+ */
+extern void (*pith_opt_current_expunged)(long unsigned int);
+
+/*
+ * Option User-Agent Header Prefix
+ */
+extern char *(*pith_opt_user_agent_prefix)(void);
+
+
+/*
+ * optional call to prompt for S/MIME passphase
+ */
+extern int (*pith_opt_smime_get_passphrase)(void);
+
+
 #endif /* PITH_OPTIONS_INCLUDED */
