@@ -1,8 +1,9 @@
 /*
- * $Id: save.h 609 2007-06-22 23:38:20Z hubert@u.washington.edu $
+ * $Id: save.h 942 2008-03-04 18:21:33Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,6 +33,12 @@
 #define SV_PRESERVE		0x10	/* preserve order			*/
 
 
+#define SSCP_NONE		0x0
+#define SSCP_INIT		0x1
+#define SSCP_END		0x2
+#define SSCP_ANSWER_IS_YES	0x4
+
+
 /* exported protoypes */
 char	   *save_get_default(struct pine *, ENVELOPE *, long, char *, CONTEXT_S **);
 void        save_get_fldr_from_env(char *, int, ENVELOPE *, struct pine *, long, char *);
