@@ -1,8 +1,9 @@
 /*
- * $Id: state.h 739 2007-10-04 17:55:10Z hubert@u.washington.edu $
+ * $Id: state.h 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006-2007 University of Washington
+ * Copyright 2006-2008 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -107,6 +108,7 @@ struct pine {
     unsigned     read_predicted:1;
 
     char         cur_folder[MAXPATH+1];
+    QUOTALIST	*quota;
     char         last_unambig_folder[MAXPATH+1];
     char         last_save_folder[MAXPATH+1];
     CONTEXT_S   *last_save_context;
@@ -168,6 +170,7 @@ struct pine {
     unsigned	 intr_pending:1;	/* received SIGINT and haven't acted */
     unsigned	 expunge_in_progress:1;	/* don't want to re-enter c-client   */
     unsigned	 never_allow_changing_from:1;	/* not even for roles */
+    unsigned	 newthread:1;		/* start a new thread on composing */
 
     unsigned	 readonly_pinerc:1;
     unsigned	 view_all_except:1;
@@ -184,6 +187,8 @@ struct pine {
     unsigned	 in_folder_screen:1;
     unsigned	 noticed_change_in_unseen:1;
     unsigned	 first_open_was_attempted:1;
+    unsigned	 force_prefer_plain:1;
+    unsigned	 force_no_prefer_plain:1;
 
     unsigned	 phone_home:1;
     unsigned     painted_body_on_startup:1;
@@ -305,6 +310,9 @@ struct pine {
 
     time_t       last_nextitem_forcechk;
 
+    MAILSTREAM  *cur_uid_stream;
+    imapuid_t    cur_uid;
+
     int		 deadlets;
 
     int		 quote_suppression_threshold;
@@ -328,11 +336,17 @@ struct pine {
     KEYWORD_S   *keywords;
     SPEC_COLOR_S *kw_colors;
 
+    ACTION_S    *default_role;		/* pointer to one of regular roles */
+
     char	 last_error[500];
     INIT_ERR_S  *init_errs;
 
     PRINT_S	*print;
 
+#ifdef SMIME
+    SMIME_STUFF_S *smime;
+#endif /* SMIME */
+
     struct variable *vars;
 };
 
