@@ -1,8 +1,9 @@
 /*
- * $Id: tempfile.h 229 2006-11-13 23:14:48Z hubert@u.washington.edu $
+ * $Id: tempfile.h 770 2007-10-24 00:23:09Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006 University of Washington
+ * Copyright 2006-2007 University of Washington
+ * Copyright 2013 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,7 +19,7 @@
 
 
 /* exported protoypes */
-char	     *tempfile_in_same_dir(char *, char *, char **, int);
+char	     *tempfile_in_same_dir(char *, char *, char **);
 int	      in_dir(char *, char *);
 
 
