@@ -1,5 +1,5 @@
 #!./tclsh
-# $Id: greeting.tcl 1106 2008-07-03 00:52:24Z mikes@u.washington.edu $
+# $Id: greeting.tcl 1204 2009-02-02 19:54:23Z hubert@u.washington.edu $
 # ========================================================================
 # Copyright 2006 University of Washington
 #
@@ -305,12 +305,6 @@ cgi_eval {
 		    }
 		  }
 		}
-
-		if {[info exists _wp(appdir_alt)] && [file isdirectory [file join .. $_wp(appdir_alt)]]} {
-		  cgi_javascript {
-		    cgi_puts "document.write('<tr><td align=right><input type=checkbox name=altui value=1 id=altui checked></td><td style=\"font-family: helvetica, sans-serif;\"><label for=altui>Try 2.0 User Interface</label></td></tr>');"
-		  }
-		}
 	      }
 	    }
 	  }
@@ -345,7 +339,7 @@ cgi_eval {
 		    }
 
 		    cgi_table_data {
-		      cgi_put [cgi_font size=-1 face=Helvetica "Use [cgi_url "SSL Session Encryption" "$_wp(serverpath)/$_wp(appdir)/help/secure.html" target=_blank]"]
+		      cgi_put [cgi_font size=-1 face=Helvetica "Use [cgi_url "SSL Session Encryption" "$_wp(serverpath)/$_wp(appdir)/$_wp(ui1dir)/help/secure.html" target=_blank]"]
 		      cgi_br
 		      set t "Session encryption over low-speed connections may slow WebPine, but prevents eavesdropping. Passwords are safely encrypted though."
 
